==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebSliderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNumberEventArgsDescriptionMetadata } from "./WebNumberEventArgsDescriptionMetadata";
import { WebSliderBaseDescriptionMetadata } from "./WebSliderBaseDescriptionMetadata";
import { WebSliderDescription } from "./WebSliderDescription";
/**
 * @hidden
 */
export let WebSliderDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSliderDescriptionMetadata extends Base {
        static b(a) {
            if (WebSliderDescriptionMetadata.a == null) {
                WebSliderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSliderDescriptionMetadata.c(WebSliderDescriptionMetadata.a);
            }
            if (a.j(WebSliderDescriptionMetadata.a)) {
                return;
            }
            a.y(WebSliderDescriptionMetadata.a);
            WebNumberEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            WebSliderBaseDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:Slider");
            a.item("__tagNameWC", "String:igc-slider");
            a.item("Value", "Number:double");
            a.item("AriaLabel", "String");
            a.item("InputRef", "EventRef::input");
            a.item("ChangeRef", "EventRef::change");
        }
        static d(a) {
            WebSliderDescriptionMetadata.b(a);
            a.aa("WebSlider", () => new WebSliderDescription());
            a.z("WebSlider", WebSliderDescriptionMetadata.a);
        }
    }
    WebSliderDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSliderDescriptionMetadata, 'WebSliderDescriptionMetadata');
    WebSliderDescriptionMetadata.a = null;
    return WebSliderDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebSliderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNumberEventArgsDescriptionMetadata } from "./WebNumberEventArgsDescriptionMetadata";
import { WebSliderBaseDescriptionMetadata } from "./WebSliderBaseDescriptionMetadata";
import { WebSliderDescription } from "./WebSliderDescription";
/**
 * @hidden
 */
export let WebSliderDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSliderDescriptionMetadata extends Base {
        static b(a) {
            if (WebSliderDescriptionMetadata.a == null) {
                WebSliderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSliderDescriptionMetadata.c(WebSliderDescriptionMetadata.a);
            }
            if (a.k(WebSliderDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebSliderDescriptionMetadata.a);
            WebNumberEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            WebSliderBaseDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:Slider");
            a.item("__tagNameWC", "String:igc-slider");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Value", "Number:double");
            a.item("AriaLabel", "String");
            a.item("InputRef", "EventRef::input");
            a.item("ChangeRef", "EventRef::change");
        }
        static d(a) {
            WebSliderDescriptionMetadata.b(a);
            a.ac("WebSlider", () => new WebSliderDescription());
            a.ab("WebSlider", WebSliderDescriptionMetadata.a);
        }
    }
    WebSliderDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSliderDescriptionMetadata, 'WebSliderDescriptionMetadata');
    WebSliderDescriptionMetadata.a = null;
    return WebSliderDescriptionMetadata;
})();
